add_concept_name

add_concept_name(table, cdm, *, column=None, name_style='{column}_name')

Add concept_name for concept_id column(s). If column is None, all columns ending with _concept_id are used.

Parameters

Name Type Description Default
table Any Ibis table with one or more *_concept_id columns. required
cdm Cdm CDM reference (concept table). required
column str or list[str] or None Concept ID column(s) to add names for; None = all *_concept_id. None
name_style str Format for name column (default “{column}_name”, e.g. condition_name). '{column}_name'

Returns

Name Type Description
ibis.expr.types.Table Table with *_name column(s) added.