compute

compute(cdm, expr, name, *, schema=None, overwrite=True)

Materialize an Ibis expression into a table in the CDM’s write schema.

Parameters

Name Type Description Default
cdm Cdm reference (database-backed). required
expr Ibis table expression to materialize. required
name Name of the new table. required
schema If set, write to this schema instead of cdm.write_schema. None
overwrite If True, replace existing table. True

Returns

Name Type Description
Ibis table reference to the new table.