summarise_cohort_overlap

summarise_cohort_overlap(cohort, cdm=None, *, cohort_id=None, strata=None)

Summarise overlap between cohorts.

For each pair of cohorts, counts subjects that are only in the reference cohort, only in the comparator cohort, or in both.

Parameters

Name Type Description Default
cohort Cohort table. required
cdm Optional Cdm for cdm_name. None
cohort_id Optional cohort_definition_id(s) to include. None
strata Optional stratification columns. None

Returns

Name Type Description
SummarisedResult